/**
 * Hook to determine if browser APIs are safely available
 *
 * @returns {boolean} - Returns true if running in the browser, false if on the server
 *
 * @example
 * ```tsx
 * 'use client';
 *
 * import { useIsBrowser } from 'nextjs-app-hooks';
 *
 * export default function MyComponent() {
 *   const isBrowser = useIsBrowser();
 *
 *   useEffect(() => {
 *     if (isBrowser) {
 *       // Safe to use browser APIs like localStorage, window, etc.
 *       localStorage.setItem('visited', 'true');
 *     }
 *   }, [isBrowser]);
 *
 *   return (
 *     <div>
 *       {isBrowser ? 'Browser APIs are available' : 'Running on the server'}
 *     </div>
 *   );
 * }
 * ```
 */
declare function useIsBrowser(): boolean;

export { useIsBrowser };
